summaryrefslogtreecommitdiffstats
path: root/korn/keditlistboxman.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/keditlistboxman.h')
-rw-r--r--korn/keditlistboxman.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/korn/keditlistboxman.h b/korn/keditlistboxman.h
index 3c213c3c..81acca89 100644
--- a/korn/keditlistboxman.h
+++ b/korn/keditlistboxman.h
@@ -21,7 +21,7 @@
#include <keditlistbox.h>
-class KConfig;
+class TDEConfig;
class TQString;
class TQWidget;
@@ -63,10 +63,10 @@ public:
/**
* Set the KConfig object (required before doing something
* @param config The KConfig-object
*/
- void setConfig( KConfig* config );
+ void setConfig( TDEConfig* config );
/**
* Sets the groupName. groupName should contain at least one %1.
* It is used for makeing groupnames.
@@ -92,7 +92,7 @@ private:
*/
void readNames();
private:
- KConfig *_config; //Stores the KConfig-object
+ TDEConfig *_config; //Stores the TDEConfig-object
TQString *_groupName; //Stores the groupName string.
TQString *_subGroupName;
int _prevCount;
@@ -138,7 +138,7 @@ signals:
* @param index The number of the item.
* this config is already in the right group.
*/
- void setDefaults( const TQString& name, const int index, KConfig* config );
+ void setDefaults( const TQString& name, const int index, TDEConfig* config );
void elementsSwapped( int, int );
void elementDeleted( int );
@@ -63,10 +63,10 @@ public:
/**
- * Set the KConfig object (required before doing something
- * @param config The KConfig-object
+ * Set the TDEConfig object (required before doing something
+ * @param config The TDEConfig-object
*/